[Qa-jenkins-scm] [jenkins.debian.net] 01/01: torbrowser tests: allow download via tor to take 10 more minutes

Holger Levsen holger at moszumanska.debian.org
Tue Mar 1 10:57:54 UTC 2016


This is an automated email from the git hooks/post-receive script.

holger pushed a commit to branch master
in repository jenkins.debian.net.

commit 8d423bd1f6b00938f98d559d4fb80a9c442ed531
Author: Holger Levsen <holger at layer-acht.org>
Date:   Tue Mar 1 11:57:42 2016 +0100

    torbrowser tests: allow download via tor to take 10 more minutes
---
 bin/test_torbrowser-launcher.sh | 8 ++++++--
 1 file changed, 6 insertions(+), 2 deletions(-)

diff --git a/bin/test_torbrowser-launcher.sh b/bin/test_torbrowser-launcher.sh
index fddca88..210355e 100755
--- a/bin/test_torbrowser-launcher.sh
+++ b/bin/test_torbrowser-launcher.sh
@@ -283,10 +283,14 @@ download_and_launch() {
 	if [ -n "$SETTINGS_DONE" ] ; then
 		announce_failure_and_exit "$(date -u) - settings dialog still there, please investigate."
 	fi
-	# allow the download to take up to ~22 minutes (1323 seconds)
+	if $VIA_TOR ; then
+		MAX_LOOP=52	# allow the download to take up to ~31 minutes (1898 seconds) via tor
+	else
+		MAX_LOOP=42	# allow the download to take up to ~22 minutes (1323 seconds) via https
+	fi
 	# ( echo -n "0" ; for i in $(seq 1 42) ; do echo -n "+$i+10" ; done ; echo ) | bc
 	# we watch the download directory and parse torbrowser-launchers stdout, so usually this loop won't run this long
-	for i in $(seq 1 42) ; do
+	for i in $(seq 1 $MAX_LOOP) ; do
 		sleep 10 ; sleep $i
 		STATUS="$(grep '^Download error:' $TBL_LOGFILE || true)"
 		if [ -n "$STATUS" ] ; then

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/qa/jenkins.debian.net.git



More information about the Qa-jenkins-scm mailing list